@@ -9,3 +9,6 @@ from .send_message import send_message
 from .send_photo import send_photo
 from .send_video import send_video
 from .set_my_commands import set_my_commands
+from .get_chat_member import get_chat_member
+from .edit_message_caption import edit_message_caption
+from .delete_message import delete_message
